A Python parser of files generated by Synergy plate readers

This is work in (hopefully) heavy progess.

For now, you can install with something along the lines of:

	pip3 install git+git://github.com/BPSB/synergy_file_reader
